camelot.camelot.model.authentication.City

Package camelot :: Package camelot :: Package model :: Module authentication :: Class City |
[hide private]
[frames] | no frames]

# Class City

source code

Nested Classes | [hide private]
| Admin

Instance Methods | [hide private]
Inherited from `GeographicBoundary`: `__unicode__`

Class Methods | [hide private]
getOrCreate(cls, country, code, name) | source code

Class Variables | [hide private]
| country = `ManyToOne('Country', required= True, ondelete= 'casc`...``
Inherited from `GeographicBoundary`: `code`, `name`

Class Variable Details | [hide private]

  ### country Value:
      ManyToOne('Country', required= True, ondelete= 'cascade', onupdate= 'c
      ascade')